#!/usr/bin/env python
# $Id$
# -*- coding: utf-8 -*-
"""
Usage: nzbmatrixget.py [OPTIONS] <NZBid from NZBMatrix.com>
        
    -u, --username=     Your account username.
    -a, --apikey=       Your API Key.
    -s, --scenename     Optional, this will restore scene names.
    -h, --help          Display this help
"""
import sys, getopt
import urllib 
import urllib2 
import gzip 
import io

class Usage(Exception):
    def __init__(self, msg):
        self.msg = msg

def generate_url(username,apikey,nzbid,scenename=None):
    url = 'http://nzbmatrix.com/api-nzb-download.php'
    data = {'id':nzbid,'username':username,'apikey':apikey}
    if scenename == 1:
        data['scenename']=scenename

    url_values = urllib.urlencode(data)
    return url + '?' + url_values

def grab_nzb(url):
    try:
        response = urllib2.urlopen(url)
    except urllib2.URLError, e:
        print >>sys.stderr, "Unable to connect to nzbmatrix.com"
        return 2
    try:
        mimetype = response.info()['Content-Type']
        if mimetype != "application/x-nzb":
            msg = response.read()
            raise KeyError(msg)
        encoding = response.info()['Content-Encoding']
        filename = response.info()['Content-Disposition'].split('\"')[1]
    except KeyError, msg:
        print >>sys.stderr, msg
        print >>sys.stderr, "The url is not valid."
        return 2
    # Get get and decompress nzb file if it is gzip encoded
    if encoding == 'gzip':
        compressed = io.BytesIO(response.read())
        data = gzip.GzipFile(fileobj=compressed).read()
    else:
        data = response.read()
    f = open(filename, 'w')
    print "Writing " + filename
    f.write(data)
    f.close()
    return 0

def main(argv=None):
    if argv is None:
        argv = sys.argv
    #parse command line options
    try:
        try:
            opts, args = getopt.getopt(argv[1:], \
                    "u:a:sh", \
                    ["username=", "apikey=", "scenename", "help"])
        except getopt.error, msg:
            raise Usage(msg)
        #process options
        apikey=""
        username=""
        scenename=None
        for o, a in opts:
            if o in ("-h", "--help"):
                print __doc__
                return 0
            if o in ("-a", "--apikey"):
                apikey=a
            if o in ("-u", "--username"):
                username=a
            if o in ("-s", "--scenename"):
                scenename=1
        if len(args) == 0:
            raise Usage("Need at least one nzbid")
    except Usage, err:
        print >>sys.stderr, err.msg
        print >>sys.stderr, "for help use --help"
        return 2
    #grab nzbs
    for nzbid in args:
        url = generate_url(username,apikey,nzbid,scenename)
        grab_nzb(url)
    return 0
    
if __name__ == "__main__":
    sys.exit(main())

# vim:syntax=python
# vim:sw=4:softtabstop=4:expandtab
